FragmentNumberSet

Struct FragmentNumberSet 

pub struct FragmentNumberSet {
    pub bitmap_base: FragmentNumber,
    pub num_bits: u32,
    pub bitmap: Vec<u32>,
}
Bitset of FragmentNumber values from bitmap_base. Analogous to SequenceNumberSet, but with FragmentNumber (u32) as the base instead of SequenceNumber.

Wire layout: bitmapBase: 4 byte (FragmentNumber, LE or BE per header) numBits: 4 byte (u32) bitmap: ceil(numBits/32) * 4 byte

Fields

bitmap_base: FragmentNumber

First fragment that the first bit is responsible for.

num_bits: u32

Number of valid bits.

bitmap: Vec<u32>

ceil(num_bits/32) u32 words.

Implementations

Source

impl FragmentNumberSet

pub fn wire_size(num_bits: u32) -> usize

Wire size in bytes.

pub fn from_missing(base: FragmentNumber, missing: &[FragmentNumber]) -> Self

Builds the set from a sorted list of missing fragments. base = smallest not-yet-acknowledged FragmentNumber.

pub fn iter_set(&self) -> impl Iterator<Item = FragmentNumber> + '_

Iterates over all set FragmentNumbers.

pub fn encoded_size(&self) -> usize

Tatsaechliche Wire-Size dieses Sets.

pub fn write_to(&self, out: &mut Vec<u8>, little_endian: bool)

Encodes the set into out.

pub fn read_from( bytes: &[u8], offset: usize, little_endian: bool, ) -> Result<(Self, usize), WireError>

Decodes a set from bytes at offset.

Errors

UnexpectedEof.