pub enum ChecksumKind {
None,
Crc32c,
Crc64,
Md5,
}Expand description
Spec 9.4.2.15.2 — selection of the messageChecksum variant. The value
is in the C bits (5+6) of the flag byte.
Variants
None
C = 00 — no checksum.
Crc32c
C = 01 — CRC-32C (RFC 4960 App. B), 4 Byte.
Crc64
C = 10 — CRC-64-XZ (ECMA-182, XZ utils), 8 Byte.
Md5
C = 11 — MD5-128 (RFC 1321), 16 Byte.
Implementations
Sourceimpl ChecksumKind
impl ChecksumKind
Sourcepub fn from_flags(flags: u8) -> Self
pub fn from_flags(flags: u8) -> Self
Extract from the C bits of a flag byte.
Sourcepub fn to_flag_bits(self) -> u8
pub fn to_flag_bits(self) -> u8
Encode into the C bits of a flag byte.